import type { AsyncDataOptions, AsyncDataRequestStatus } from 'nuxt/app';
import type { ContentSourceMap, QueryParams } from '@sanity/client';
import type { EncodeDataAttributeFunction } from '@sanity/core-loader/encode-data-attribute';
import { type Ref } from 'vue';
export interface UseSanityQueryOptions<T> extends AsyncDataOptions<T> {
    client?: 'default' | 'minimal';
    perspective?: 'drafts' | 'published' | 'raw';
}
export interface SanityQueryResponse<T> {
    data: T;
    sourceMap?: ContentSourceMap;
    encodeDataAttribute?: EncodeDataAttributeFunction;
}
export type AsyncSanityData<T, E> = _AsyncSanityData<T, E> & Promise<_AsyncSanityData<T, E>>;
interface AsyncDataExecuteOptions {
    _initial?: boolean;
    dedupe?: boolean;
}
export interface _AsyncSanityData<T, E> {
    data: Ref<T>;
    sourceMap: Ref<ContentSourceMap | null>;
    encodeDataAttribute: Ref<EncodeDataAttributeFunction | (() => void)>;
    pending: Ref<boolean>;
    refresh: (opts?: AsyncDataExecuteOptions) => Promise<void>;
    execute: (opts?: AsyncDataExecuteOptions) => Promise<void>;
    error: Ref<E | null>;
    status: Ref<AsyncDataRequestStatus>;
}
export declare function useLazySanityQuery<T = unknown, E = Error>(query: string, params?: QueryParams, options?: UseSanityQueryOptions<SanityQueryResponse<T | null>>): AsyncSanityData<T | null, E>;
export declare function useSanityQuery<T = unknown, E = Error>(query: string, _params?: QueryParams, options?: UseSanityQueryOptions<SanityQueryResponse<T | null>>, lazy?: boolean): AsyncSanityData<T | null, E>;
export {};
